Authors
=======
* John Whitlock (`jwhitlock <https://github.com/jwhitlock>`_, John-Whitlock@ieee.org)
* Juha Yrjölä (`juyrjola <https://github.com/juyrjola>`_, juha.yrjola@iki.fi)
* Kevin Diale (`powersurge360 <https://github.com/powersurge360>`_, powersurge360@gmail.com)
* Adam Lawrence (`alaw005 <https://github.com/alaw005>`_, alaw005@gmail.com)
* Dave Kroondyk (`davekaro <https://github.com/davekaro>`_, davekaro@gmail.com)
* Joshua Goodwin (`jclgoodwin <https://github.com/jclgoodwin>`_, j@joshuagoodw.in)
